#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/install.sh - phpmyadmin41 installation
#
# Creation   :  2017-04-28 holbru
# Last update:  $Id: install.sh 46988 2017-09-03 19:17:29Z hbfl $
#
# Copyright (c) 2017-2019 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=phpmyadmin41


# ---------------------------------------------------------------------------
# extract phpMyAdmin (tarball, required from pack-eis :-( )
# ---------------------------------------------------------------------------

if tar --help | grep -q 'no-overwrite-dir'
then
    taroption='--no-overwrite-dir'
else
    taroption=''
fi

if tar --help | grep -q 'keep-directory-symlink'
then
    taroption="${taroption} --keep-directory-symlink"
fi

_tar_file=$(ls /tmp/${package_name}_inst.tar.*)

cd /
tar $taroption -xf ${_tar_file}  2>/tmp/install.log
if [ ${?} -ne 0 ]
then
    . /var/install/include/eislib
    mecho --error "installation of ${package_name} failed!"
    mecho --error "aborting installation!"
    echo
    anykey
    exit 1
fi

if [ ! -s /tmp/install.log ] # empty?
then                         # yes...
    rm -f /tmp/install.log   # remove it
fi

rm -f ${_tar_file}

mv /tmp/${package_name}-files2.txt /etc/filelist.d/.


if [ -d /var/lib/phpmyadmin/tmp ]
then
    rm -f /var/lib/phpmyadmin/tmp/sess_*
    mv /var/lib/phpmyadmin/tmp /srv/www/${package_name}/tmp
fi

mkdir -p /srv/www/${package_name}/tmp

if [ -d /var/lib/phpmyadmin/log ]
then
    mv /var/lib/phpmyadmin/log /srv/www/${package_name}/log
fi

mkdir -p /srv/www/${package_name}/log

if [ -d /var/lib/phpmyadmin/phpMyAdmin/tmp ]
then
    mv /var/lib/phpmyadmin/phpMyAdmin/tmp /srv/www/${package_name}/phpMyAdmin/tmp
fi

mkdir -p /srv/www/${package_name}/phpMyAdmin/tmp
chown -R wwwrun.nogroup /srv/www/${package_name}/phpMyAdmin
chown -R wwwrun.nogroup /srv/www/${package_name}/tmp
chown -R wwwrun.nogroup /srv/www/${package_name}/log

if [ -f /var/lib/phpmyadmin/phpmyadmin.htpasswd ]
then
    mv /var/lib/phpmyadmin/phpmyadmin.htpasswd  /srv/www/${package_name}/phpmyadmin41.htpasswd
fi

rmdir --ignore-fail-on-non-empty /var/lib/phpmyadmin 2>/dev/null


# ---------------------------------------------------------------------------
# create default config
# ---------------------------------------------------------------------------
if [ -f "/etc/config.d/${package_name}" ] || [ -f /etc/config.d/phpmyadmin ]
then
    update=true
fi

/var/install/config.d/${package_name}-update.sh

# remove config update script
rm -f /var/install/config.d/${package_name}-update.sh

# remove old config
rm -f /etc/config.d/phpmyadmin

# ---------------------------------------------------------------------------
# start configuration
# ---------------------------------------------------------------------------
if ${update:-false}
then
    /var/install/config.d/${package_name}.sh --quiet --no-check
fi

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
