#!/bin/sh
# ---------------------------------------------------------------------------
# /var/install/config.d/phpmyadmin41-update.sh - parameter update script
#
# Creation:     2006-09-15 starwarsfan
# Last Update:  $Id: phpmyadmin41-update.sh 46402 2017-06-17 18:02:38Z hbfl $
#
# Copyright (c) 2006-2009 the eisfair team, team(at)eisfair(dot)org
# Copyright (c) 2015-2019 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ---------------------------------------------------------------------------

# set package name
package_name=phpmyadmin41

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# include apache2 config
. /etc/config.d/apache2

#exec 2>/tmp/phpmyadmin55-update-trace$$.log
#set -x

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
get_defaults()
{
    VERSION=$(sed -n '/<version>/ s# ##g; s#</*version>##gp' \
              /var/install/packages/${package_name})

    START_PHPMYADMIN41='no'

    # phpMyAdmin used as subdomain 'phpmyadmin.meine.de'
    PHPMYADMIN41_SUBDOMAIN='no'
    PHPMYADMIN41_SUBDOMAIN_NAME="phpmyadmin41.${APACHE2_SERVER_NAME#*.}"
    PHPMYADMIN41_SUBDOMAIN_PORT='80'
    PHPMYADMIN41_SUBDOMAIN_ADMIN=''
    PHPMYADMIN41_SUBDOMAIN_FORCE_SSL='no'
    PHPMYADMIN41_SUBDOMAIN_SSL_PORT='443'
    PHPMYADMIN41_SUBDOMAIN_SSL_CERT="apache2-${package_name}"

    # phpMyAdmin used as host alias 'www.meine.de/phpmyadmin'
    PHPMYADMIN41_HOST='yes'
    PHPMYADMIN41_HOST_NAME="${APACHE2_SERVER_NAME}"
    PHPMYADMIN41_HOST_ALIAS="${package_name}"
    PHPMYADMIN41_HOST_FORCE_SSL='no'

    # access method
    PHPMYADMIN41_ACCESS_CONTROL='no'
    PHPMYADMIN41_ACCESS_ALL='no'
    PHPMYADMIN41_ACCESS_AUTH='no'
    PHPMYADMIN41_ACCESS_AUTH_SEND_MAIL_FROM=''
    PHPMYADMIN41_ACCESS_HOST=''
    PHPMYADMIN41_ACCESS_IP=''
    PHPMYADMIN41_ACCESS_LOCAL='no'

    # servers
    PHPMYADMIN41_SERVER_N='1'
    PHPMYADMIN41_SERVER_1_NAME=''
    PHPMYADMIN41_SERVER_1_ACTIVE='no'
    PHPMYADMIN41_SERVER_1_HOST='localhost'
    PHPMYADMIN41_SERVER_1_PORT=''

    PHPMYADMIN41_SERVER_1_AUTH_METHOD='cookie'

    PHPMYADMIN41_SERVER_1_CONNECT_TYPE='tcp'
    PHPMYADMIN41_SERVER_1_COMPRESS='no'

    PHPMYADMIN41_SERVER_1_ONLY_DB_N='0'
    PHPMYADMIN41_SERVER_1_ONLY_DB_1_NAME=''
    PHPMYADMIN41_SERVER_1_VERBOSE=''

    PHPMYADMIN41_SERVER_1_ADVANCED_FEATURES='no'

#    PHPMYADMIN41_SERVER_1_USE_SSL='no'

    PHPMYADMIN41_SERVER_1_PMADB_USE='no'
    PHPMYADMIN41_SERVER_1_PMADB_NAME='phpmyadmin'
    PHPMYADMIN41_SERVER_1_CONTROLUSER=''
    PHPMYADMIN41_SERVER_1_CONTROLPASS=''

    PHPMYADMIN41_MISC_FEATURES='no'

    #security
    PHPMYADMIN41_SHOW_CHG_PASSWORD='no'
    PHPMYADMIN41_ALLOW_ARBITRARY_SERVER='no'
    PHPMYADMIN41_LOGIN_COOKIE_RECALL='yes'
    PHPMYADMIN41_LOGIN_COOKIE_VALIDITY='1800'


    PHPMYADMIN41_PMA_ABSOLUTE_URI=''
    PHPMYADMIN41_PMA_NORELATION_DISABLE_WARNING='yes'

    PHPMYADMIN41_UPLOAD_DIR=''
    PHPMYADMIN41_SAVE_DIR=''

    PHPMYADMIN41_RECODING_ENGINE='auto'
    PHPMYADMIN41_ICONV_EXTRA_PARAMS='//TRANSLIT'

    PHPMYADMIN41_BROWSE_MIME='yes'
    PHPMYADMIN41_DEFAULT_LANGUAGE='de-utf-8'
    PHPMYADMIN41_DEFAULT_COLLATION='latin1_swedish_ci'
    PHPMYADMIN41_DISABLE_SUHOSIN_WARNING='no'
}

# ---------------------------------------------------------------------------
# Read old configuration and update old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # -------------------
    # Read current values
    if [ -f /etc/config.d/${package_name} ]
    then
        # backup old configfile
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi


    if [ -f /etc/config.d/phpmyadmin ] &&
       [ ! -f /etc/config.d/${package_name} ]
    then
        . /etc/config.d/phpmyadmin
        old_conf=true

        idx=1
        while [ ${idx} -le ${PHPMYADMIN_SERVER_N} ]
        do
            eval           authHTTP='${PHPMYADMIN_SERVER_'${idx}'_AUTH_HTTP}'
            eval         authCookie='${PHPMYADMIN_SERVER_'${idx}'_AUTH_COOKIE}'
            eval         authConfig='${PHPMYADMIN_SERVER_'${idx}'_AUTH_CONFIG}'
            eval authConfigUsername='${PHPMYADMIN_SERVER_'${idx}'_USER}'
            eval authConfigPassword='${PHPMYADMIN_SERVER_'${idx}'_PASSWORD}'
            if [ "${authHTTP}" = "yes" ]
            then
                eval PHPMYADMIN_SERVER_${idx}_AUTH_METHOD='http'
            elif [ "${authCookie}" = "yes" ]
            then
                eval PHPMYADMIN_SERVER_${idx}_AUTH_METHOD='cookie'
            elif [ "${authConfig}" = "yes" ]
            then
                eval PHPMYADMIN_SERVER_${idx}_AUTH_METHOD='config:${authConfigUsername}:${authConfigPassword}'
            fi

            idx=$((${idx} + 1))
        done
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    #------------------------------------------------------------------------
    printgpl --conf ${package_name} '2006-09-15' 'starwarsfan'
    #------------------------------------------------------------------------
    echo "# phpMyAdmin-VERSION ${VERSION}"

    #------------------------------------------------------------------------
    printgroup 'phpMyAdmin configuration'
    #------------------------------------------------------------------------


    if ${old_conf:-false}
    then
        START_PHPMYADMIN41=${START_PHPMYADMIN}
    fi

    printvar 'START_PHPMYADMIN41'
    printcomment        'Use: yes or no'


    #------------------------------------------------------------------------
    printcustomgroup 'phpMyAdmin used as subdomain (virtualhost)' <<!EOC
    Example: 'phpmyadmin.meine.de'
!EOC
    #------------------------------------------------------------------------


    printvar 'PHPMYADMIN41_SUBDOMAIN'
    printcomment        'Use: yes or no'

    printvar 'PHPMYADMIN41_SUBDOMAIN_NAME'
    printcomment        'Name of the subdomain to use'

    printvar 'PHPMYADMIN41_SUBDOMAIN_PORT'
    printcomment        'Default 80'

    printvar 'PHPMYADMIN41_SUBDOMAIN_ADMIN'
    printcomment        'Email address from server admin'

    printvar 'PHPMYADMIN41_SUBDOMAIN_FORCE_SSL'
    printcomment        'Use ssl -> https to connect the service'

    printvar 'PHPMYADMIN41_SUBDOMAIN_SSL_PORT'
    printcomment        'Default 443'

    printvar 'PHPMYADMIN41_SUBDOMAIN_SSL_CERT'
    printcomment        'Name from SSL-Certificat'


    #------------------------------------------------------------------------
    printcustomgroup 'phpMyAdmin used as alias' <<!EOC
    Example: 'www.meine.de/phpmyadmin'
!EOC
    #------------------------------------------------------------------------


    if ${old_conf:-false}
    then
        if [ -n "${PHPMYADMIN_INSTALL_HOST}" ]
        then
            PHPMYADMIN_HOST='yes'
            PHPMYADMIN_HOST_NAME="${PHPMYADMIN_INSTALL_HOST}"
        fi

        PHPMYADMIN41_HOST=${PHPMYADMIN_HOST}
        PHPMYADMIN41_HOST_NAME=${PHPMYADMIN_HOST_NAME}

        if [ -n "${PHPMYADMIN_INSTALL_FOLDER}" ]
        then
            PHPMYADMIN_INSTALL_HOST_ALIAS=${PHPMYADMIN_INSTALL_FOLDER}
        fi

        if [ -n "${PHPMYADMIN_INSTALL_HOST_ALIAS}" ]
        then
            PHPMYADMIN_HOST_ALIAS="${PHPMYADMIN_INSTALL_HOST_ALIAS}"
        fi

        PHPMYADMIN41_HOST_ALIAS=${PHPMYADMIN_HOST_ALIAS}

        hostssl="${PHPMYADMIN_FORCE_SSL}"

        if [ -n "${hostssl}" ]
        then
            eval PHPMYADMIN_HOST_FORCE_SSL="${PHPMYADMIN_FORCE_SSL}"
        fi

        PHPMYADMIN41_HOST_FORCE_SSL=${PHPMYADMIN_HOST_FORCE_SSL}
    fi

    printvar 'PHPMYADMIN41_HOST'
    printcomment        'Use yes or no'

    printvar 'PHPMYADMIN41_HOST_NAME'
    printcomment        'Hostname to contact phpmyadmin'

    printvar 'PHPMYADMIN41_HOST_ALIAS'
    printcomment        'Name to connect the service: default ->  phpmyadmin'

    printvar 'PHPMYADMIN41_HOST_FORCE_SSL'
    printcomment        'Use ssl -> https to connect the service'


    #-------------------------------------------------------------------------
    printgroup 'Access Control'
    #-------------------------------------------------------------------------


 if ${old_conf:-false}
    then
        PHPMYADMIN41_ACCESS_CONTROL=${PHPMYADMIN_ACCESS_CONTROL}
        PHPMYADMIN41_ACCESS_ALL=${PHPMYADMIN_ACCESS_ALL}
        PHPMYADMIN41_ACCESS_AUTH=${PHPMYADMIN_ACCESS_AUTH}
        PHPMYADMIN41_ACCESS_AUTH_SEND_MAIL_FROM=${PHPMYADMIN_ACCESS_AUTH_SEND_MAIL_FROM}
        PHPMYADMIN41_ACCESS_HOST=${PHPMYADMIN_ACCESS_HOST}
        PHPMYADMIN41_ACCESS_IP=${PHPMYADMIN_ACCESS_IP}
        PHPMYADMIN41_ACCESS_LOCAL=${PHPMYADMIN_ACCESS_LOCAL}
    fi

    printvar 'PHPMYADMIN41_ACCESS_CONTROL'
    printcomment        'Use: yes or no, access control available'

    printvar 'PHPMYADMIN41_ACCESS_ALL'
    printcomment        'Use: yes or no, access for all over the world'

    printvar 'PHPMYADMIN41_ACCESS_AUTH'
    printcomment        'Use: yes or no, access with user and password'

    printvar 'PHPMYADMIN41_ACCESS_AUTH_SEND_MAIL_FROM'
    printcomment        'Use: empty, no mail or Mailadress from Admin,'
    printcomment        'required for outgoing mail'

    printvar 'PHPMYADMIN41_ACCESS_HOST'
    printcomment        'Use: hostname or domain,'
    printcomment        'multiple with space as separator'

    printvar 'PHPMYADMIN41_ACCESS_IP'
    printcomment        'Use: ip for your host or network,'
    printcomment        'multiple with space as separator'

    printvar 'PHPMYADMIN41_ACCESS_LOCAL'
    printcomment        'Use: yes or no, only local access'


    #-------------------------------------------------------------------------
    printgroup 'Servers'
    #-------------------------------------------------------------------------


    if ${old_conf:-false}
    then
        PHPMYADMIN41_SERVER_N=${PHPMYADMIN_SERVER_N}
    fi

    printvar 'PHPMYADMIN41_SERVER_N'
    printcomment        'Number of Servers'

    # begin PHPMYADMIN41_SERVER_N
    idx=1
    while [ ${idx} -le ${PHPMYADMIN41_SERVER_N} ]
    do
        if ${old_conf:-false}
        then
            eval PHPMYADMIN41_SERVER_${idx}_NAME='${PHPMYADMIN_SERVER_'${idx}'_NAME}'
            eval PHPMYADMIN41_SERVER_${idx}_ACTIVE='${PHPMYADMIN_SERVER_'${idx}'_ACTIVE}'
            eval PHPMYADMIN41_SERVER_${idx}_HOST='${PHPMYADMIN_SERVER_'${idx}'_HOST}'
            eval PHPMYADMIN41_SERVER_${idx}_PORT='${PHPMYADMIN_SERVER_'${idx}'_PORT}'
            eval PHPMYADMIN41_SERVER_${idx}_AUTH_METHOD='${PHPMYADMIN_SERVER_'${idx}'_AUTH_METHOD}'
            eval PHPMYADMIN41_SERVER_${idx}_CONNECT_TYPE='${PHPMYADMIN_SERVER_'${idx}'_CONNECT_TYPE}'
            eval PHPMYADMIN41_SERVER_${idx}_COMPRESS='${PHPMYADMIN_SERVER_'${idx}'_COMPRESS}'
            eval PHPMYADMIN41_SERVER_${idx}_ONLY_DB_N='${PHPMYADMIN_SERVER_'${idx}'_ONLY_DB_N}'
        fi

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_NAME'
        printcomment    'Use a name what ever you want. The entered value is'
        printcomment    'only for your overview of different servers'

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_ACTIVE'
        printcomment    'Is this server active? Use: yes or no'

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_HOST'
        printcomment    'FQDN or IP of this server'

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_PORT'
        printcomment    'Portnumber to use for connection.'
        printcomment    'connect port is also uniq indentifier'

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_AUTH_METHOD'
        printcomment    "'http', 'cookie' or 'config:<username>:<password>'"

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_CONNECT_TYPE'
        printcomment    "Type of the connection: 'tcp' or 'socket'"

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_COMPRESS'
        printcomment    'Use: yes or no'

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_ONLY_DB_N'
        printcomment    'If no database selection should be visible, enter'
        printcomment    "the amount of the db's to show here"


        eval dbs_to_show='${PHPMYADMIN41_SERVER_'${idx}'_ONLY_DB_N}'

        dbs_to_show=${dbs_to_show:-0} # Set to 0 if empty

        idx2=1
        while [ ${idx2} -le ${dbs_to_show} ]
        do
            if ${old_conf:-false}
            then
                eval PHPMYADMIN41_SERVER_${idx}_ONLY_DB_${idx2}_NAME='${PHPMYADMIN_SERVER_'${idx}'_ONLY_DB_'${idx2}'_NAME}'
            fi

            printvar 'PHPMYADMIN41_SERVER_'${idx}'_ONLY_DB_'${idx2}'_NAME'
            printcomment    'Name of the db to show'

            idx2=$((${idx2} + 1))
        done

        if ${old_conf:-false}
        then
            eval PHPMYADMIN41_SERVER_${idx}_VERBOSE='${PHPMYADMIN_SERVER_'${idx}'_VERBOSE}'
            eval PHPMYADMIN41_SERVER_${idx}_ADVANCED_FEATURES='${PHPMYADMIN_SERVER_'${idx}'_ADVANCED_FEATURES}'
#            eval PHPMYADMIN41_SERVER_${idx}_NO_PASSWORD='${PHPMYADMIN_SERVER_'${idx}'_USE_SSL}'

            eval pmadb_controluser='${PHPMYADMIN_SERVER_'${idx}'_CONTROLUSER}'

            if [ -n "${pmadb_controluser}" ]
            then
                eval PHPMYADMIN41_SERVER_${idx}_PMADB_USE='yes'
            else
                eval PHPMYADMIN41_SERVER_${idx}_PMADB_USE='no'
            fi

            eval PHPMYADMIN41_SERVER_${idx}_PMADB_NAME='${PHPMYADMIN_SERVER_'${idx}'_PMADB}'
            eval PHPMYADMIN41_SERVER_${idx}_CONTROLUSER='${PHPMYADMIN_SERVER_'${idx}'_CONTROLUSER}'
            eval PHPMYADMIN41_SERVER_${idx}_CONTROLPASS='${PHPMYADMIN_SERVER_'${idx}'_CONTROLPASS}'
        fi

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_VERBOSE'
        printcomment    'Name of this server to display in the header'


        printvar 'PHPMYADMIN41_SERVER_'${idx}'_ADVANCED_FEATURES'
        printcomment    'Activate database for advanced features. If this'
        printcomment    "is set to 'yes' then the database entered on"
        printcomment    'PHPMYADMIN41_SERVER_#_PMADB will be created'
        printcomment    'Use: yes or no'

#        printvar 'PHPMYADMIN41_SERVER_'${idx}'_USE_SSL'
#        printcomment    'Use SSL for connection to this MySQL server'

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_PMADB_USE'
        printcomment    'Use: yes or no'

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_PMADB_NAME'
        printcomment    'Database for advanced features. Normally you'
        printcomment    'do not change this value'

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_CONTROLUSER'
        printcomment    'phpMyAdmin control user'

        printvar 'PHPMYADMIN41_SERVER_'${idx}'_CONTROLPASS'
        printcomment    'phpMyAdmin control user password'

        idx=$((${idx} + 1))
    done


    #-------------------------------------------------------------------------
    printgroup 'Misc settings'
    #-------------------------------------------------------------------------


    if ${old_conf:-false}
    then
        PHPMYADMIN41_MISC_FEATURES=${PHPMYADMIN_MISC_FEATURES}
        PHPMYADMIN41_SHOW_CHG_PASSWORD=${PHPMYADMIN_SHOW_CHG_PASSWORD}
        PHPMYADMIN41_ALLOW_ARBITRARY_SERVER=${PHPMYADMIN_ALLOW_ARBITRARY_SERVER}
        PHPMYADMIN41_LOGIN_COOKIE_RECALL=${PHPMYADMIN_LOGIN_COOKIE_RECALL}
        PHPMYADMIN41_LOGIN_COOKIE_VALIDITY=${PHPMYADMIN_LOGIN_COOKIE_VALIDITY}
        PHPMYADMIN41_PMA_ABSOLUTE_URI=${PHPMYADMIN_PMA_ABSOLUTE_URI}

        if [ -n "${PHPMYADMIN_PMA_NORELATION_DISABLEWARNING}" ]
        then
            PHPMYADMIN_PMA_NORELATION_DISABLE_WARNING=${PHPMYADMIN_PMA_NORELATION_DISABLEWARNING}
        fi

        PHPMYADMIN41_PMA_NORELATION_DISABLE_WARNING=${PHPMYADMIN_PMA_NORELATION_DISABLE_WARNING}

        if [ -n "${PHPMYADMIN_UPLOADDIR}" ]
        then
            PHPMYADMIN_UPLOAD_DIR=${PHPMYADMIN_UPLOADDIR}
        fi

        PHPMYADMIN41_UPLOAD_DIR=${PHPMYADMIN_UPLOAD_DIR}

        if [ -n "${PHPMYADMIN_SAVEDIR}" ]
        then
            PHPMYADMIN_SAVE_DIR=${PHPMYADMIN_SAVEDIR}
        fi

        PHPMYADMIN41_SAVE_DIR=${PHPMYADMIN_SAVE_DIR}

        if [ -n "${PHPMYADMIN_RECODINGENGINE}" ]
        then
            PHPMYADMIN_RECODING_ENGINE=${PHPMYADMIN_RECODINGENGINE}
        fi

        PHPMYADMIN41_RECODING_ENGINE=${PHPMYADMIN_RECODING_ENGINE}

        if [ -n "${PHPMYADMIN_ICONVEXTRAPARAMS}" ]
        then
            PHPMYADMIN_ICONV_EXTRA_PARAMS=${PHPMYADMIN_ICONVEXTRAPARAMS}
        fi

        PHPMYADMIN41_ICONV_EXTRA_PARAMS=${PHPMYADMIN_ICONV_EXTRA_PARAMS}

        if [ -n "${PHPMYADMIN_BROWSEMIME}" ]
        then
            PHPMYADMIN_BROWSE_MIME=${PHPMYADMIN_BROWSEMIME}
        fi

        PHPMYADMIN41_BROWSE_MIME=${PHPMYADMIN_BROWSE_MIME}

        if [ -n "${PHPMYADMIN_DEFAULTLANGUAGE}" ]
        then
            PHPMYADMIN_DEFAULT_LANGUAGE=${PHPMYADMIN_DEFAULTLANGUAGE}
        fi

        PHPMYADMIN41_DEFAULT_LANGUAGE=${PHPMYADMIN_DEFAULT_LANGUAGE}
        PHPMYADMIN41_DISABLE_SUHOSIN_WARNING=${PHPMYADMIN_DISABLE_SUHOSIN_WARNING}
    fi

    printvar 'PHPMYADMIN41_MISC_FEATURES'
    printcomment        'Use: yes or no'


    #-------------------------------------------------------------------------
    printgroup 'Security settings'
    #-------------------------------------------------------------------------


    printvar 'PHPMYADMIN41_SHOW_CHG_PASSWORD'
    printcomment        'Use: yes or no'

    printvar 'PHPMYADMIN41_ALLOW_ARBITRARY_SERVER'
    printcomment        'Use: yes or no'

    printvar 'PHPMYADMIN41_LOGIN_COOKIE_RECALL'
    printcomment        'Define whether the previous login should be'
    printcomment        'recalled or not in cookie authentication mode.'

    printvar 'PHPMYADMIN41_LOGIN_COOKIE_VALIDITY'
    printcomment        'Define how long is login cookie valid. (seconds)'

    printvar 'PHPMYADMIN41_PMA_ABSOLUTE_URI'
    printcomment        'Full URI to pMA'

    printvar 'PHPMYADMIN41_PMA_NORELATION_DISABLE_WARNING'
    printcomment        'Use: yes or no'


    #-------------------------------------------------------------------------
    printgroup 'Settings for script- and dump-file up- and download'
    #-------------------------------------------------------------------------


    printvar 'PHPMYADMIN41_UPLOAD_DIR'
    printcomment        'Destination directory for uploaded sql scripts'

    printvar 'PHPMYADMIN41_SAVE_DIR'
    printcomment        'Destination directory for db dump files'


    #-------------------------------------------------------------------------
    printgroup 'Settings for character encoding'
    #-------------------------------------------------------------------------


    printvar 'PHPMYADMIN41_RECODING_ENGINE'
    printcomment        'Function which will be used for character set'
    printcomment        'conversion'

    printvar 'PHPMYADMIN41_ICONV_EXTRA_PARAMS'
    printcomment        'Some parameters for iconv used in charset conversion'


    #------------------------------------------------------------------------
    printgroup 'Miscellaneous'
    #------------------------------------------------------------------------


    printvar 'PHPMYADMIN41_BROWSE_MIME'
    printcomment        'Enable MIME-transformations'

    printvar 'PHPMYADMIN41_DEFAULT_LANGUAGE'
    printcomment        'Number of language to use, check manual for'
    printcomment        'corresponding settings'

    printvar 'PHPMYADMIN41_DISABLE_SUHOSIN_WARNING'
    printcomment        'Disable display of a warning if Suhosin is'
    printcomment        'detected on a server'

    printvar 'PHPMYADMIN41_DEFAULT_COLLATION'
    printcomment        'Default collation'

    #------------------------------------------------------------------------
    printend
    #------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
#----------------------------------------------------------------------------
printgpl --check ${package_name} "2006-09-15" "starwarsfan" >/etc/check.d/${package_name}
#----------------------------------------------------------------------------
cat >>/etc/check.d/${package_name} <<EOF
# Variable                               OPT_VARIABLE                            VARIABLE_N                           VALUE
START_PHPMYADMIN41                         -                                         -                                YESNO

PHPMYADMIN41_SUBDOMAIN                     START_PHPMYADMIN41                        -                                YESNO
PHPMYADMIN41_SUBDOMAIN_NAME                PHPMYADMIN41_SUBDOMAIN                    -                                FQDN
PHPMYADMIN41_SUBDOMAIN_PORT                PHPMYADMIN41_SUBDOMAIN                    -                                PORT
PHPMYADMIN41_SUBDOMAIN_ADMIN               PHPMYADMIN41_SUBDOMAIN                    -                                MAILADDR
PHPMYADMIN41_SUBDOMAIN_FORCE_SSL           PHPMYADMIN41_SUBDOMAIN                    -                                YESNO
PHPMYADMIN41_SUBDOMAIN_SSL_PORT            PHPMYADMIN41_SUBDOMAIN_FORCE_SSL          -                                EPORT
PHPMYADMIN41_SUBDOMAIN_SSL_CERT            PHPMYADMIN41_SUBDOMAIN_FORCE_SSL          -                                PHPMYADMIN_COMMON_SSL_CERTS_CUI

PHPMYADMIN41_HOST                          START_PHPMYADMIN41                        -                                YESNO
PHPMYADMIN41_HOST_NAME                     PHPMYADMIN41_HOST                         -                                PHPMYADMIN_COMMON_APACHE2_HOST_CUI
PHPMYADMIN41_HOST_ALIAS                    PHPMYADMIN41_HOST                         -                                NOBLANK
PHPMYADMIN41_HOST_FORCE_SSL                PHPMYADMIN41_HOST                         -                                YESNO

PHPMYADMIN41_ACCESS_CONTROL                START_PHPMYADMIN41                        -                                YESNO
PHPMYADMIN41_ACCESS_ALL                    PHPMYADMIN41_ACCESS_CONTROL               -                                YESNO
PHPMYADMIN41_ACCESS_AUTH                   !PHPMYADMIN41_ACCESS_ALL                  -                                YESNO
PHPMYADMIN41_ACCESS_AUTH_SEND_MAIL_FROM    PHPMYADMIN41_ACCESS_AUTH                  -                                EMAILADDR
PHPMYADMIN41_ACCESS_HOST                   !PHPMYADMIN41_ACCESS_ALL                  -                                NONE
PHPMYADMIN41_ACCESS_IP                     !PHPMYADMIN41_ACCESS_ALL                  -                                NONE
PHPMYADMIN41_ACCESS_LOCAL                  !PHPMYADMIN41_ACCESS_ALL                  -                                YESNO

PHPMYADMIN41_SERVER_N                      START_PHPMYADMIN41                        -                                NUMERIC
PHPMYADMIN41_SERVER_%_NAME                 START_PHPMYADMIN41                        PHPMYADMIN41_SERVER_N            NONE
PHPMYADMIN41_SERVER_%_ACTIVE               START_PHPMYADMIN41                        PHPMYADMIN41_SERVER_N            YESNO
PHPMYADMIN41_SERVER_%_HOST                 PHPMYADMIN41_SERVER_%_ACTIVE              PHPMYADMIN41_SERVER_N            NONE
PHPMYADMIN41_SERVER_%_PORT                 PHPMYADMIN41_SERVER_%_ACTIVE              PHPMYADMIN41_SERVER_N            PHPMYADMIN_COMMON_DATABASE_PORT_CUI


PHPMYADMIN41_SERVER_%_CONNECT_TYPE         PHPMYADMIN41_SERVER_%_ACTIVE              PHPMYADMIN41_SERVER_N            PHPMYADMIN_COMMON_SERVER_CONNECT_TYPE_CUI

PHPMYADMIN41_SERVER_%_COMPRESS             PHPMYADMIN41_SERVER_%_ACTIVE              PHPMYADMIN41_SERVER_N            YESNO
PHPMYADMIN41_SERVER_%_AUTH_METHOD          PHPMYADMIN41_SERVER_%_ACTIVE              PHPMYADMIN41_SERVER_N            PHPMYADMIN_COMMON_GET_AUTH_METHOD_CUI

PHPMYADMIN41_SERVER_%_ONLY_DB_N            PHPMYADMIN41_SERVER_%_ACTIVE              PHPMYADMIN41_SERVER_N            NUMERIC
PHPMYADMIN41_SERVER_%_ONLY_DB_%_NAME       PHPMYADMIN41_SERVER_%_ACTIVE              PHPMYADMIN41_SERVER_%_ONLY_DB_N  NOTEMPTY
PHPMYADMIN41_SERVER_%_VERBOSE              PHPMYADMIN41_SERVER_%_ACTIVE              PHPMYADMIN41_SERVER_N            NONE

PHPMYADMIN41_SERVER_%_ADVANCED_FEATURES    PHPMYADMIN41_SERVER_%_ACTIVE              PHPMYADMIN41_SERVER_N            YESNO

#PHPMYADMIN41_SERVER_%_USE_SSL              PHPMYADMIN41_SERVER_%_ADVANCED_FEATURES   PHPMYADMIN41_SERVER_N            YESNO

PHPMYADMIN41_SERVER_%_PMADB_USE            PHPMYADMIN41_SERVER_%_ADVANCED_FEATURES   PHPMYADMIN41_SERVER_N            YESNO
PHPMYADMIN41_SERVER_%_PMADB_NAME           PHPMYADMIN41_SERVER_%_PMADB_USE           PHPMYADMIN41_SERVER_N            NOTEMPTY
PHPMYADMIN41_SERVER_%_CONTROLUSER          PHPMYADMIN41_SERVER_%_PMADB_USE           PHPMYADMIN41_SERVER_N            NOTEMPTY
PHPMYADMIN41_SERVER_%_CONTROLPASS          PHPMYADMIN41_SERVER_%_PMADB_USE           PHPMYADMIN41_SERVER_N            PASSWD


PHPMYADMIN41_MISC_FEATURES                 START_PHPMYADMIN41                        -                     YESNO

PHPMYADMIN41_SHOW_CHG_PASSWORD             PHPMYADMIN41_MISC_FEATURES                -                     YESNO
PHPMYADMIN41_ALLOW_ARBITRARY_SERVER        PHPMYADMIN41_MISC_FEATURES                -                     YESNO
PHPMYADMIN41_LOGIN_COOKIE_RECALL           PHPMYADMIN41_MISC_FEATURES                -                     YESNO
PHPMYADMIN41_LOGIN_COOKIE_VALIDITY         PHPMYADMIN41_MISC_FEATURES                -                     NUMERIC

PHPMYADMIN41_PMA_ABSOLUTE_URI              PHPMYADMIN41_MISC_FEATURES                -                     EFQDN
PHPMYADMIN41_PMA_NORELATION_DISABLE_WARNING PHPMYADMIN41_MISC_FEATURES                -                     YESNO

PHPMYADMIN41_UPLOAD_DIR                    PHPMYADMIN41_MISC_FEATURES                -                     E_ABS_PATH
PHPMYADMIN41_SAVE_DIR                      PHPMYADMIN41_MISC_FEATURES                -                     E_ABS_PATH

PHPMYADMIN41_RECODING_ENGINE               PHPMYADMIN41_MISC_FEATURES                -                     PHPMYADMIN_COMMON_RECODING_ENGINE_CUI
PHPMYADMIN41_ICONV_EXTRA_PARAMS            PHPMYADMIN41_MISC_FEATURES                -                     NONE
PHPMYADMIN41_BROWSE_MIME                   PHPMYADMIN41_MISC_FEATURES                -                     YESNO
PHPMYADMIN41_DEFAULT_LANGUAGE              PHPMYADMIN41_MISC_FEATURES                -                     PHPMYADMIN_COMMON_DEFAULT_LANGUAGE_OLD_CUI
PHPMYADMIN41_DISABLE_SUHOSIN_WARNING       PHPMYADMIN41_MISC_FEATURES                -                     YESNO
PHPMYADMIN41_DEFAULT_COLLATION             PHPMYADMIN41_MISC_FEATURES                -                     PHPMYADMIN41_DEFCOLL_CUI
EOF

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${package_name}
    chown root /etc/check.d/${package_name}




cat >/var/install/bin/pre-setup-services-apache2-config-modules-${package_name}-edit <<EOFG
#!/bin/sh
#----------------------------------------------------------------------------
#  edit file generated by ${package_name} version: ${VERSION}
#
#  Do not edit this file, it was auto created
#  Creation Date: ${EISDATE} Time: ${EISTIME}
#----------------------------------------------------------------------------

. /var/install/include/configlib

. /etc/config.d/apache2

main_servername="\${APACHE2_SERVER_NAME}"
server_name=\${main_servername}
server_name_help=\${main_servername}
server_name_dialog=\${main_servername}

idx=1

while [ "\${idx}" -le "\${APACHE2_VHOST_N}" ]
do
    eval active='\${APACHE2_VHOST_'\${idx}'_ACTIVE}'

    if [ "\${active}" != "yes" ]
    then
       idx=\$((\${idx} + 1))
       continue
    fi

    eval servername='\${APACHE2_VHOST_'\${idx}'_SERVER_NAME}'

    if [ \${servername} != \${main_servername} ]
    then
        server_name="\${server_name}|"\${servername}
        server_name_help="\${server_name_help}, "\${servername}
        server_name_dialog="\${server_name_dialog},"\${servername}
    fi

    idx=\$((\${idx} + 1))
done

sed -i "s#sellist=.*#sellist=\"\${server_name_dialog}\"#" \\
       /var/install/dialog.d/PHPMYADMIN_COMMON_APACHE2_HOST_CUI.sh


#-------------------------------------------------------------------------
printgpl --check_exp ${package_name} '2006-09-16' 'starwarsfan' >/etc/check.d/${package_name}.exp
#-------------------------------------------------------------------------
cat >>/etc/check.d/${package_name}.exp <<EOF
PHPMYADMIN_COMMON_APACHE2_HOST_CUI     = '\${server_name}'
                                       : 'Only this server allowed: \${server_name_help}'

PHPMYADMIN_COMMON_GET_AUTH_METHOD_CUI  = 'http|cookie|config:(RE:NOTEMPTY):(RE:NOTEMPTY)|signon'
                                       : 'Only "http", "cookie", "config:<username>:<password>" or "signon" is valid'

PHPMYADMIN_COMMON_DEFAULT_LANGUAGE_OLD_CUI = 'af-iso-8859-1|af-utf-8|ar-win1256|ar-utf-8|az-iso-8859-9|az-utf-8|becyr-win1251|becyr-utf-8|belat-utf-8|bg-win1251|bg-koi8-r|bg-utf-8|bs-win1250|bs-utf-8|ca-iso-8859-1|ca-utf-8|cs-iso-8859-2|cs-win1250|cs-utf-8|da-iso-8859-1|da-utf-8|de-iso-8859-1|de-iso-8859-15|de-utf-8| el-iso-8859-7|el-utf-8|en-iso-8859-1|en-iso-8859-15|en-utf-8|es-iso-8859-1|es-iso-8859-15|es-utf-8| et-iso-8859-1|et-utf-8|eu-iso-8859-1|eu-utf-8|fa-win1256|fa-utf-8|fi-iso-8859-1|fi-iso-8859-15|fi-utf-8|fr-iso-8859-1|fr-iso-8859-15fr-utf-8|gl-iso-8859-1|gl-utf-8|he-iso-8859-8-i|he-utf-8|hi-utf-8|hr-win1250|hr-iso-8859-2|hr-utf-8|hu-iso-8859-2|hu-utf-8|id-iso-8859-1|id-utf-8|it-iso-8859-1|it-iso-8859-15|it-utf-8|ja-euc|ja-sjis|ja-utf-8|ko-euc-kr|ko-utf-8|ka-utf-8|lt-win1257|lt-utf-8|lv-win1257|lv-utf-8|mn-utf-8|ms-iso-8859-1|ms-utf-8|nl-iso-8859-1|nl-iso-8859-15|nl-utf-8|no-iso-8859-1|no-utf-8|pl-iso-8859-2|pl-win1250|pl-utf-8|ptbr-iso-8859-1|ptbr-utf-8|pt-iso-8859-1|pt-iso-8859-15|pt-utf-8|ro-iso-8859-1|ro-utf-8|ru-win1251| ru-cp-866|ru-koi8-r|ru-utf-8|sk-iso-8859-2|sk-win1250|sk-utf-8|sl-iso-8859-2|sl-win1250|sl-utf-8|sq-iso-8859-1|sq-utf-8|srlat-win1250|srlat-utf-8|srcyr-win1251|srcyr-utf-8|sv-iso-8859-1|sv-utf-8|th-tis-620|th-utf-8|tr-iso-8859-9|tr-utf-8|tt-iso-8859-9|tt-utf-8|uk-win1251|uk-utf-8|zhtw-big5|zhtw-utf-8|zh-gb2312|zh-utf-8'
                                       : 'Only one of the values "af-iso-8859-1", "af-utf-8", "ar-win1256", "ar-utf-8", "az-iso-8859-9", "az-utf-8", "becyr-win1251", "becyr-utf-8", "belat-utf-8", "bg-win1251", "bg-koi8-r", "bg-utf-8", "bs-win1250", "bs-utf-8", "ca-iso-8859-1", "ca-utf-8", "cs-iso-8859-2", "cs-win1250", "cs-utf-8", "da-iso-8859-1", "da-utf-8", "de-iso-8859-1", "de-iso-8859-15", "de-utf-8", " el-iso-8859-7", "el-utf-8", "en-iso-8859-1", "en-iso-8859-15", "en-utf-8", "es-iso-8859-1", "es-iso-8859-15", "es-utf-8", " et-iso-8859-1", "et-utf-8", "eu-iso-8859-1", "eu-utf-8", "fa-win1256", "fa-utf-8", "fi-iso-8859-1", "fi-iso-8859-15", "fi-utf-8", "fr-iso-8859-1", "fr-iso-8859-15fr-utf-8", "gl-iso-8859-1", "gl-utf-8", "he-iso-8859-8-i", "he-utf-8", "hi-utf-8", "hr-win1250", "hr-iso-8859-2", "hr-utf-8", "hu-iso-8859-2", "hu-utf-8", "id-iso-8859-1", "id-utf-8", "it-iso-8859-1", "it-iso-8859-15", "it-utf-8", "ja-euc", "ja-sjis", "ja-utf-8", "ko-euc-kr", "ko-utf-8", "ka-utf-8", "lt-win1257", "lt-utf-8", "lv-win1257", "lv-utf-8", "mn-utf-8", "ms-iso-8859-1", "ms-utf-8", "nl-iso-8859-1", "nl-iso-8859-15", "nl-utf-8", "no-iso-8859-1", "no-utf-8", "pl-iso-8859-2", "pl-win1250", "pl-utf-8", "ptbr-iso-8859-1", "ptbr-utf-8", "pt-iso-8859-1", "pt-iso-8859-15", "pt-utf-8", "ro-iso-8859-1", "ro-utf-8", "ru-win1251", " ru-cp-866", "ru-koi8-r", "ru-utf-8", "sk-iso-8859-2", "sk-win1250", "sk-utf-8", "sl-iso-8859-2", "sl-win1250", "sl-utf-8", "sq-iso-8859-1", "sq-utf-8", "srlat-win1250", "srlat-utf-8", "srcyr-win1251", "srcyr-utf-8", "sv-iso-8859-1", "sv-utf-8", "th-tis-620", "th-utf-8", "tr-iso-8859-9", "tr-utf-8", "tt-iso-8859-9", "tt-utf-8", "uk-win1251", "uk-utf-8", "zhtw-big5", "zhtw-utf-8", "zh-gb2312" or "zh-utf-8" is valid'

PHPMYADMIN_COMMON_RECODING_ENGINE_CUI  = 'auto|iconv|recode'
                                       : 'For recoding engine only the settings "auto", "iconv" and "recode" possible'

PHPMYADMIN_COMMON_SERVER_CONNECT_TYPE_CUI = 'tcp|socket'
                                       : 'Only "tcp" or "socket" is valid'

PHPMYADMIN_COMMON_SSL_CERTS_CUI        = '()|(RE:NOTEMPTY)'
                                       : 'SSL Server Certificat Name'

PHPMYADMIN41_DEFCOLL_CUI               = 'utf8_unicode_ci|utf8_turkish_ci|utf8_swedish_ci|utf8_spanish_ci|utf8_spanish2_ci|utf8_slovenian_ci|utf8_slovak_ci|utf8_romanian_ci|utf8_roman_ci|utf8_polish_ci|utf8_persian_ci|utf8_lithuanian_ci|utf8_latvian_ci|utf8_icelandic_ci|utf8_general_ci|utf8_estonian_ci|utf8_danish_ci|utf8_czech_ci|utf8_bin|ujis_japanese_ci|ujis_bin|ucs2_unicode_ci|ucs2_turkish_ci|ucs2_swedish_ci|ucs2_spanish_ci|ucs2_spanish2_ci|ucs2_slovenian_ci|ucs2_slovak_ci|ucs2_romanian_ci|ucs2_roman_ci|ucs2_polish_ci|ucs2_persian_ci|ucs2_lithuanian_ci|ucs2_latvian_ci|ucs2_icelandic_ci|ucs2_general_ci|ucs2_estonian_ci|ucs2_danish_ci|ucs2_czech_ci|ucs2_bin|tis620_thai_ci|tis620_bin|swe7_swedish_ci|swe7_bin|sjis_japanese_ci|sjis_bin|macroman_general_ci|macroman_bin|macce_general_ci|macce_bin|latin7_general_cs|latin7_general_ci|latin7_estonian_cs|latin7_bin|latin5_turkish_ci|latin5_bin|latin2_hungarian_ci|latin2_general_ci|latin2_czech_cs|latin2_croatian_ci|latin2_bin|latin1_swedish_ci|latin1_spanish_ci|latin1_german2_ci|latin1_german1_ci|latin1_general_cs|latin1_general_ci|latin1_danish_ci|latin1_bin|koi8u_general_ci|koi8u_bin|koi8r_general_ci|koi8r_bin|keybcs2_general_ci|keybcs2_bin|hp8_english_ci|hp8_bin|hebrew_general_ci|hebrew_bin|greek_general_ci|greek_bin|geostd8_general_ci|geostd8_bin|gbk_chinese_ci|gbk_bin|gb2312_chinese_ci|gb2312_bin|euckr_korean_ci|euckr_bin|dec8_swedish_ci|dec8_bin|cp932_japanese_ci|cp932_bin|cp866_general_ci|cp866_bin|cp852_general_ci|cp852_bin|cp850_general_ci|cp850_bin|cp1257_lithuanian_ci|cp1257_general_ci|cp1257_bin|cp1256_general_ci|cp1256_bin|cp1251_ukrainian_ci|cp1251_general_cs|cp1251_general_ci|cp1251_bulgarian_ci|cp1251_bin|cp1250_general_ci|cp1250_czech_cs|cp1250_croatian_ci|cp1250_bin|binary|big5_chinese_ci|big5_bin|ascii_general_ci|ascii_bin|armscii8_general_ci|armscii8_bin'
                                       : 'Valid value = utf8_unicode_ci, utf8_turkish_ci, utf8_swedish_ci, utf8_spanish_ci, utf8_spanish2_ci, utf8_slovenian_ci, utf8_slovak_ci, utf8_romanian_ci, utf8_roman_ci, utf8_polish_ci, utf8_persian_ci, utf8_lithuanian_ci, utf8_latvian_ci, utf8_icelandic_ci, utf8_general_ci, utf8_estonian_ci, utf8_danish_ci, utf8_czech_ci, utf8_bin, ujis_japanese_ci, ujis_bin, ucs2_unicode_ci, ucs2_turkish_ci, ucs2_swedish_ci, ucs2_spanish_ci, ucs2_spanish2_ci, ucs2_slovenian_ci, ucs2_slovak_ci, ucs2_romanian_ci, ucs2_roman_ci, ucs2_polish_ci, ucs2_persian_ci, ucs2_lithuanian_ci, ucs2_latvian_ci, ucs2_icelandic_ci, ucs2_general_ci, ucs2_estonian_ci, ucs2_danish_ci, ucs2_czech_ci, ucs2_bin, tis620_thai_ci, tis620_bin, swe7_swedish_ci, swe7_bin, sjis_japanese_ci, sjis_bin, macroman_general_ci, macroman_bin, macce_general_ci, macce_bin, latin7_general_cs, latin7_general_ci, latin7_estonian_cs, latin7_bin, latin5_turkish_ci, latin5_bin, latin2_hungarian_ci, latin2_general_ci, latin2_czech_cs, latin2_croatian_ci, latin2_bin, latin1_swedish_ci, latin1_spanish_ci, latin1_german2_ci, latin1_german1_ci, latin1_general_cs, latin1_general_ci, latin1_danish_ci, latin1_bin, koi8u_general_ci, koi8u_bin, koi8r_general_ci, koi8r_bin, keybcs2_general_ci, keybcs2_bin, hp8_english_ci, hp8_bin, hebrew_general_ci, hebrew_bin, greek_general_ci, greek_bin, geostd8_general_ci, geostd8_bin, gbk_chinese_ci, gbk_bin, gb2312_chinese_ci, gb2312_bin, euckr_korean_ci, euckr_bin, dec8_swedish_ci, dec8_bin, cp932_japanese_ci, cp932_bin, cp866_general_ci, cp866_bin, cp852_general_ci, cp852_bin, cp850_general_ci, cp850_bin, cp1257_lithuanian_ci, cp1257_general_ci, cp1257_bin, cp1256_general_ci, cp1256_bin, cp1251_ukrainian_ci, cp1251_general_cs, cp1251_general_ci, cp1251_bulgarian_ci, cp1251_bin, cp1250_general_ci, cp1250_czech_cs, cp1250_croatian_ci, cp1250_bin, binary, big5_chinese_ci, big5_bin, ascii_general_ci, ascii_bin, armscii8_general_ci, armscii8_bin'

PHPMYADMIN_COMMON_DATABASE_PORT_CUI    = '(RE:PORT)'
                                       : 'Use database port 3306, 3307 ...'

EOF

    # Set rights for exp file
    chmod 0600 /etc/check.d/${package_name}.exp
    chown root /etc/check.d/${package_name}.exp


EOFG

    chmod 0755 /var/install/bin/pre-setup-services-apache2-config-modules-${package_name}-edit



#-------------------------------------------------------------------------
printgpl --check_ext ${package_name} '2006-09-16' 'starwarsfan' >/etc/check.d/${package_name}.ext
#-------------------------------------------------------------------------
cat >>/etc/check.d/${package_name}.ext <<EOF
if ( "\${PHPMYADMIN41_LOGIN_COOKIE_VALIDITY}" < 300 )
then
    warning "PHPMYADMIN41_LOGIN_COOKIE_VALIDITY should be a usable amount of time. You entered a time of less than five minutes. This is only a hint, phpMyAdmin is working with this setting."
fi

set cuname=0
set uname=0
foreach i in phpmyadmin41_server_n
do
    if ( phpmyadmin41_server_%_controluser[i] == "root" || phpmyadmin41_server_%_controluser[i] == "eis" )
    then
        set cuname=phpmyadmin41_server_%_controluser[i]
        error "PHPMYADMIN41_SERVER_\${i}_CONTROLUSER '\${cuname}' is not allowed"
    fi

#    if (phpmyadmin41_server_%_advanced_features[i] == "yes")
#    then
#        if (phpmyadmin41_server_%_host[i] == "localhost" ||
#            phpmyadmin41_server_%_host[i] == "127.0.0.1" &&
#            phpmyadmin41_server_%_use_ssl[i] == "yes")
#        then
#            error "PHPMYADMIN41_SERVER_\${i}_USE_SSL = 'yes' is not usable with PHPMYADMIN41_SERVER_\${i}_HOST = 'localhost or 127.0.0.1'"
#        fi
#
#        if (phpmyadmin41_server_%_use_ssl[i] == "yes")
#        then
#            set client_certificat = "no"
#            stat("/etc/mysql/client-cert.pem", res)
#            if (res_res == "OK")
#            then
#                set client_certificat
#            fi
#
#            if (!client_certificat)
#            then
#                error "PHPMYADMIN41_SERVER_\${i}_USE_SSL = 'yes', to work with this feature, please install the MariaDB/MySQL client certificat."
#            fi
#        fi
#    fi

#    if (phpmyadmin41_server_%_only_db_n[i] > "0" &&
#        phpmyadmin41_server_%_only_db_%_name[i][i] == "")
#    then
#         error "PHPMYADMIN41_SERVER_\${i}_ONLY_DB_\${i}_NAME is empty"
#    fi

    if (phpmyadmin41_server_%_auth_method[i] == "http")
    then
        if (phpmyadmin41_access_control == "yes")
        then
            error "PHPMYADMIN41_SERVER_\${i}_AUTH_METHOD = 'http' is not usable with PHPMYADMIN41_ACCESS_CONTROL = 'yes', use AUTH_METHOD 'cookie' instead."
        fi
    fi
done

if (phpmyadmin41_access_auth_send_mail_from)
then
    set mail = "no"
    stat("/usr/sbin/sendmail", res)
    if (res_res == "OK")
    then
        set mail
    fi

    if (!mail)
    then
        error "No mail package found, please install any mail package before you activate this function!"
    fi
fi

EOF

    # Set rights for ext file
    chmod 0600 /etc/check.d/${package_name}.ext
    chown root /etc/check.d/${package_name}.ext
}


# ----------------------------------------------------------------------------
# main
# ----------------------------------------------------------------------------
main()
{
    get_defaults

    # write default config file
    make_config_file /etc/default.d/${package_name}

    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file

    exit 0
}

# ----------------------------------------------------------------------------
# call function main
# ----------------------------------------------------------------------------
main "${@}"

# ----------------------------------------------------------------------------
# end
# ----------------------------------------------------------------------------
