#!/bin/sh
# ---------------------------------------------------------------------------
# /var/install/config.d/phpmyadmin41.sh   phpMyAdmin configuration
#
# Creation:     2006-09-15 starwarsfan
# Last Update:  $Id: phpmyadmin41.sh 61995 2019-01-05 10:20:55Z hbfl $
#
# Copyright (c) 2006--2009 the eisfair team, team(at)eisfair(dot)org
# Maintained by Yves Schumann, yves(at)eisfair(dot)org
# Copyright (c) 2015-2019 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ---------------------------------------------------------------------------

# set package name
package_name='phpmyadmin41'

. /var/install/include/eislib

#debug=true

if ${debug:-false}
then
    exec 2>/tmp/$(basename ${0})-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

VERSION=$(sed -n '/<version>/ s# ##g; s#</*version>##gp' \
          /var/install/packages/${package_name})

. /etc/config.d/${package_name}
. /etc/config.d/apache2

ownerToUse='wwwrun:nogroup'

package_folder="/srv/www/${package_name}"
package_path="${package_folder}/phpMyAdmin"

vhost_alias_path='/etc/apache2/vhost'
vhost_include_path='/etc/apache2/mods-include'
vhost_enabled_path='/etc/apache2/mods-enabled'
vhost_available_path='/etc/apache2/mods-available'


config_dir='/etc/phpMyAdmin'
config_php=/etc/phpMyAdmin/config41.inc.php

pwgen_version='2.6.1'
check_pwgen=1

project_name="$(echo ${package_name} | tr [:lower:] [:upper:])"

apache_user='wwwrun'
apache_group='nogroup'

ASK='/var/install/bin/ask'
MKTEMP='/usr/bin/mktemp'
RM='/usr/bin/rm'

# ---------------------------------------------------------------------------
# Setup the boolean values as php they want
# ---------------------------------------------------------------------------
createBooleanValues()
{

    case ${PHPMYADMIN41_HOST_FORCE_SSL} in
    yes)
        _PHPMYADMIN41_FORCE_SSL=true
        web_ssl=true
        ;;
    no)
        _PHPMYADMIN41_FORCE_SSL=false
        web_ssl=false
        ;;
    esac

    case ${PHPMYADMIN41_MISC_FEATURES} in
    yes)
        case ${PHPMYADMIN41_SHOW_CHG_PASSWORD} in
        yes)
            PHPMYADMIN41_SHOW_CHG_PASSWORD=true
            ;;
        no)
            PHPMYADMIN41_SHOW_CHG_PASSWORD=false
            ;;
        esac

        case ${PHPMYADMIN41_ALLOW_ARBITRARY_SERVER} in
        yes)
            PHPMYADMIN41_ALLOW_ARBITRARY_SERVER=true
            ;;
        no)
            PHPMYADMIN41_ALLOW_ARBITRARY_SERVER=false
            ;;
        esac

        case ${PHPMYADMIN41_LOGIN_COOKIE_RECALL} in
        yes)
            PHPMYADMIN41_LOGIN_COOKIE_RECALL=true
            ;;
        no)
            PHPMYADMIN41_LOGIN_COOKIE_RECALL=false
            ;;
        esac

        case ${PHPMYADMIN41_PMA_NORELATION_DISABLE_WARNING} in
        yes)
            PHPMYADMIN41_PMA_NORELATION_DISABLE_WARNING=true
            ;;
        no)
            PHPMYADMIN41_PMA_NORELATION_DISABLE_WARNING=false
            ;;
        esac

        case ${PHPMYADMIN41_BROWSE_MIME} in
        yes)
            PHPMYADMIN41_BROWSE_MIME=true
            ;;
        no)
            PHPMYADMIN41_BROWSE_MIME=false
            ;;
        esac

        case ${PHPMYADMIN41_DISABLE_SUHOSIN_WARNING} in
        yes)
            PHPMYADMIN41_DISABLE_SUHOSIN_WARNING=true
            ;;
        no)
            PHPMYADMIN41_DISABLE_SUHOSIN_WARNING=false
            ;;
        esac
        ;;
    esac

}


# ----------------------------------------------------------------------------
# Create config.inc.php
# ----------------------------------------------------------------------------
createConfigIncPhp()
{
    myecho "Write 'phpMyAdmin' config ..."

    cat > ${config_php} <<EOF
<?php
/**--------------------------------------------------------------------------
 * Config file generated by phpmyadmin eisfair setup for phpMyAdmin41 ${VERSION}
 *
 * Copyright (c) 2006-2019 the eisfair team, team(at)eisfair(dot)org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *---------------------------------------------------------------------------
 *
 * Do not edit this file, edit /etc/config.d/phpmyadmin41
 * Creation Date: ${EISDATE} Time: ${EISTIME}
 *
 *---------------------------------------------------------------------------
 */

/* Global configuration */
\$cfg['VersionCheck']                          = false;
\$cfg['SessionSavePath']                       = "${package_folder}/tmp";
\$cfg['DefaultConnectionCollation']            = "${PHPMYADMIN41_DEFAULT_COLLATION:-latin1_swedish_ci}";
EOF


    cat >> ${config_php} <<EOF
/* Servers configuration */
\$i = 0;

EOF
    # ------------------------------------
    # Begin idx -le ${PHPMYADMIN41_SERVER_N}
    idx=1

    # ------------------------
    # Count for active servers
    idx1=1
    while [ ${idx} -le ${PHPMYADMIN41_SERVER_N} ]
    do

        eval active='${PHPMYADMIN41_SERVER_'${idx}'_ACTIVE}'
        # -------------
        # Begin $active
        if [ "${active}" != 'yes' ]
        then
            idx=$((${idx} + 1))
            continue
        fi

        eval         host='${PHPMYADMIN41_SERVER_'${idx}'_HOST}'
        eval         port='${PHPMYADMIN41_SERVER_'${idx}'_PORT}'
        eval connect_type='${PHPMYADMIN41_SERVER_'${idx}'_CONNECT_TYPE}'
        eval         comp='${PHPMYADMIN41_SERVER_'${idx}'_COMPRESS}'

        case ${comp} in
        yes)
            compress='true'
            ;;
        no)
            compress='false'
            ;;
        esac

        # ---------------------------------------------------
        # Extract the settings for the type of authentication
        eval authMethod='${PHPMYADMIN41_SERVER_'${idx}'_AUTH_METHOD}'
        local authType=$(echo ${authMethod} | cut -d ":" -f 1)

        user=''
        password=''
        if [ "${authType}" = 'http' ]
        then
            # ------------------------------------------------
            # Auth via http is requested. No more steps to do.
            fileconf='http'
        elif [ "${authType}" = 'cookie' ]
        then
            # --------------------------------------------------
            # Auth via cookie is requested. No more steps to do.
            fileconf='cookie'
        elif [ "${authType}" = 'config' ]
        then
            # ------------------------------------------------
            # Auth via configuration is requested. Extract the
            # username and password to use.
            user=$(echo ${authMethod} | cut -d ":" -f 2)
            password=$(echo ${authMethod} | cut -d ":" -f 3)
            fileconf="config:${user}"
        elif [ "${authType}" = 'signon' ]
        then
            # ----------------------------------------------------------
            # Auth via single sign on is requested. No more steps to do.
            fileconf='signon'
        fi

        # --------------------------
        # Create list of DBs to show
        eval onlyDBAmount='${PHPMYADMIN41_SERVER_'${idx}'_ONLY_DB_N}'

        if [ ${onlyDBAmount:-0} -eq 0 ]
        then
            # ------------
            # Show all DBs
            dbsToShow="''"
        else
            idx2=1
            separator=''
            while [ ${idx2} -le ${onlyDBAmount} ]
            do
                eval currentDB='${PHPMYADMIN41_SERVER_'${idx}'_ONLY_DB_'${idx2}'_NAME}'
                _dbsToShow="${_dbsToShow}${separator}'${currentDB}'"
                    separator=', '
                    idx2=$((${idx2} + 1))
            done
            dbsToShow="array(${_dbsToShow})"
        fi

        eval verbose='${PHPMYADMIN41_SERVER_'${idx}'_VERBOSE}'

        cat >> ${config_php} <<EOF
/* Server ${host} (${fileconf}) [${idx1}] */
\$i++;
\$cfg['Servers'][\$i]['host']                  = "${host}";
EOF

        if [ "${host}" != 'localhost' ]
        then
            cat >> ${config_php} <<EOF
\$cfg['Servers'][\$i]['port']                  = "${port}";
EOF
        fi

        cat >> ${config_php} <<EOF
\$cfg['Servers'][\$i]['user']                  = "${user}";
\$cfg['Servers'][\$i]['password']              = "${password}";
\$cfg['Servers'][\$i]['auth_type']             = "${authType}";
\$cfg['Servers'][\$i]['extension']             = 'mysqli';
\$cfg['Servers'][\$i]['connect_type']          = "${connect_type}";
EOF

        if [ "${connect_type}" = 'socket' ]
        then
            my_server=$(find /etc/config.d  -maxdepth 1 \
                        -name 'mariadb' -printf '%f\n' -o \
                        -name 'mariadb[0-9]*' -printf '%f\n' -o \
                        -name 'mysql' -printf '%f\n' -o \
                        -name 'mysql[0-9]*' -printf '%f\n')

            if [ -n "${my_server}" ]
            then
                for SERVER in ${my_server}
                do
                    . /etc/config.d/${SERVER}

                    var_prefix=$(echo ${SERVER} | tr [:lower:] [:upper:])

                    eval connect_port='${'${var_prefix}'_CONNECT_PORT}'

                    my_path=$(echo ${SERVER} | sed 's|[^[:digit:]]||g')

                    if [ ${connect_port:-0} -eq ${port:-1} ]
                    then
                        break
                    fi
                done

                if [ -n "${my_path}" ]
                then
                    . /srv/mysql/defaults.info
                elif [ -f /var/lib/mysql/defaults.info ]
                then
                    # old version, deprecated
                    . /var/lib/mysql/defaults.info
                else
                    mysql_basedir=$(awk -F' = ' '/basedir/ {print $2}' /etc/my.cnf)

                    mysql_socket=$(${mysql_basedir}/bin/mysqld --print-defaults |
                                    tr " " "\n" |
                                    awk -F'=' '/socket/ {print $2}')
                fi

                cat >> ${config_php} <<EOF
\$cfg['Servers'][\$i]['socket']                = "${mysql_socket}";
EOF
            fi
        fi

        cat >> ${config_php} <<EOF
\$cfg['Servers'][\$i]['compress']              = ${compress};
\$cfg['Servers'][\$i]['only_db']               = ${dbsToShow};
\$cfg['Servers'][\$i]['verbose']               = "${verbose}";

EOF

        eval advancedFeaturesActive='${PHPMYADMIN41_SERVER_'${idx}'_ADVANCED_FEATURES}'
        if [ "${advancedFeaturesActive}" = 'yes' ]
        then
            eval pmadb_use='${PHPMYADMIN41_SERVER_'${idx}'_PMADB_USE}'

            if [ "${pmadb_use}" = "yes" ]
            then
                eval  pmadb_name='${PHPMYADMIN41_SERVER_'${idx}'_PMADB_NAME}'
                eval controluser='${PHPMYADMIN41_SERVER_'${idx}'_CONTROLUSER}'
                eval controlpass='${PHPMYADMIN41_SERVER_'${idx}'_CONTROLPASS}'

                cat >> ${config_php} <<EOF

\$cfg['Servers'][\$i]['pmadb']                 = "${pmadb_name}";
\$cfg['Servers'][\$i]['controluser']           = "${controluser}";
\$cfg['Servers'][\$i]['controlpass']           = "${controlpass}";

\$cfg['Servers'][\$i]['bookmarktable']         = 'pma_bookmark';
\$cfg['Servers'][\$i]['relation']              = 'pma_relation';
\$cfg['Servers'][\$i]['table_info']            = 'pma_table_info';
\$cfg['Servers'][\$i]['table_coords']          = 'pma_table_coords';
\$cfg['Servers'][\$i]['pdf_pages']             = 'pma_pdf_pages';
\$cfg['Servers'][\$i]['column_info']           = 'pma_column_info';
\$cfg['Servers'][\$i]['history']               = 'pma_history';
\$cfg['Servers'][\$i]['table_uiprefs']         = 'pma_table_uiprefs';
\$cfg['Servers'][\$i]['tracking']              = 'pma_tracking';
\$cfg['Servers'][\$i]['designer_coords']       = 'pma_designer_coords';
\$cfg['Servers'][\$i]['designer_settings']     = 'pma_designer_settings';
\$cfg['Servers'][\$i]['userconfig']            = 'pma_userconfig';
\$cfg['Servers'][\$i]['recent']                = 'pma_recent';
\$cfg['Servers'][\$i]['favorite']              = 'pma_favorite';
\$cfg['Servers'][\$i]['users']                 = 'pma_users';
\$cfg['Servers'][\$i]['usergroups']            = 'pma_usergroups';
\$cfg['Servers'][\$i]['navigationhiding']      = 'pma_navigationhiding';
\$cfg['Servers'][\$i]['savedsearches']         = 'pma_savedsearches';
\$cfg['Servers'][\$i]['central_columns']       = 'pma_central_columns';
\$cfg['Servers'][\$i]['export_templates']      = 'pma_export_templates';
EOF

            fi
            # ---------------------------------
            # Extract the setting for ssl usage
            eval use_ssl='${PHPMYADMIN41_SERVER_'${idx}'_USE_SSL}'
            if [ "${use_ssl:-no}" = "yes" ]
            then
                cat >> ${config_php} <<EOF

\$cfg['Servers'][\$i]['ssl']                   = true;
\$cfg['Servers'][\$i]['key']                   = '/etc/mysql/client-key.pem';
\$cfg['Servers'][\$i]['cert']                  = '/etc/mysql/client-cert.pem';
\$cfg['Servers'][\$i]['ca']                    = '/etc/mysql/ca-cert.pem';
\$cfg['Servers'][\$i]['capath']                = NULL;
\$cfg['Servers'][\$i]['cipher']                = NULL;
EOF
            fi

            # end count for active
            idx1=$((${idx1} + 1))
        fi

        # end idx -le ${PHPMYADMIN41_SERVER_N}
        idx=$((${idx} + 1))
    done

    if [ ${check_pwgen} -eq 1 ]
    then
        check_package "pwgen" "${pwgen_version}"
        check_pwgen=${?}
    fi

    if [ ${check_pwgen} -eq 0 ]
    then
        BLOWFISH_SECRET=$(pwgen -s -1 46)
    fi

    cat >> ${config_php} <<EOF

/* End of servers configuration */

/* Configuration of secret for cookie encryption */
\$cfg['blowfish_secret']                       = "${BLOWFISH_SECRET}";

EOF


    if [ "${PHPMYADMIN41_MISC_FEATURES}" = 'yes' ]
    then
        cat >> ${config_php} <<EOF

/* Configuration of security settings */
\$cfg['ShowChgPassword']                       = ${PHPMYADMIN41_SHOW_CHG_PASSWORD};
\$cfg['AllowArbitraryServer']                  = ${PHPMYADMIN41_ALLOW_ARBITRARY_SERVER};
\$cfg['LoginCookieRecall']                     = ${PHPMYADMIN41_LOGIN_COOKIE_RECALL};
\$cfg['LoginCookieValidity']                   = ${PHPMYADMIN41_LOGIN_COOKIE_VALIDITY};
\$cfg['PmaAbsoluteUri']                        = "${PHPMYADMIN41_PMA_ABSOLUTE_URI}";
\$cfg['PmaNoRelation_DisableWarning']          = ${PHPMYADMIN41_PMA_NORELATION_DISABLE_WARNING};

/* Configuration of file up- and download */
\$cfg['UploadDir']                             = "${PHPMYADMIN41_UPLOAD_DIR}";
\$cfg['SaveDir']                               = "${PHPMYADMIN41_SAVE_DIR}";

\$cfg['RecodingEngine']                        = "${PHPMYADMIN41_RECODING_ENGINE}";
\$cfg['IconvExtraParams']                      = "${PHPMYADMIN41_ICONV_EXTRA_PARAMS}";

/* Misc */
\$cfg['BrowseMIME']                            = ${PHPMYADMIN41_BROWSE_MIME};
\$cfg['DefaultLang']                           = "${PHPMYADMIN41_DEFAULT_LANGUAGE}";
\$cfg['SuhosinDisableWarning']                 = ${PHPMYADMIN41_DISABLE_SUHOSIN_WARNING};
EOF

    fi

    cat >> ${config_php} <<EOF

?>

EOF
    chown -R ${ownerToUse} ${config_dir}
}

# ----------------------------------------------------------------------------
# Check the given username because 'root' and 'eis' is not allowed
# ----------------------------------------------------------------------------
checkCredentials()
{
    rtc=0
    idx=1
    while [ ${idx} -le ${PHPMYADMIN41_SERVER_N} ]
    do
        # ---------------------------------------------------
        # Extract the settings for the type of authentication
        eval authMethod='${PHPMYADMIN41_SERVER_'${idx}'_AUTH_METHOD}'
        local authType=$(echo ${authMethod} | cut -d ":" -f 1)
        local user=''
        if [ "${authType}" = 'config' ]
        then
            # ----------------------------------------------------------
            # Auth via configuration is requested. Extract the username.
            user=$(echo ${authMethod} | cut -d ":" -f 2)
            if [ "${user}" = 'root' ] || [ "${user}" = 'eis' ]
            then
                mecho --error "Username '${user}' is not allowed, please change this!"
                rtc=1
            fi
        fi
        idx=$((${idx} + 1))
    done
    if [ ${rtc} -ne 0 ]
    then
        exit ${rtc}
    fi
    return
}

# ---------------------------------------------------------------------------
# create vhosts
# ---------------------------------------------------------------------------
create_vhosts()
{
    _vhost_action="${1}"

    eval _host='${'${project_name}'_HOST}'

    if [ "${_host}" = "yes" ]
    then
        eval inst_servername='${'${project_name}'_HOST_NAME}'
        eval      inst_alias='${'${project_name}'_HOST_ALIAS}'

        if [ "${_vhost_action}" = "remove" ]
        then
            rm -f ${vhost_alias_path}/host-${inst_servername}-${inst_alias}
            rm -f ${vhost_alias_path}/vhost-${inst_servername}-${inst_alias}
            _apache_conf=true
        else
            check_apache
        fi
    fi
}

# ---------------------------------------------------------------------------
# create apache
# ---------------------------------------------------------------------------
check_apache()
{
    main_servername="${APACHE2_SERVER_NAME}"

    idy=1
    while [ "${idy}" -le "${APACHE2_VHOST_N}" ]
    do
        eval active='${APACHE2_VHOST_'${idy}'_ACTIVE}'

        if [ "${active}" != "yes" ]
        then
            idy=$((${idy} + 1))
            continue
        fi

        eval servername='${APACHE2_VHOST_'${idy}'_SERVER_NAME}'

        if [ -z "${server_name}" ]
        then
            server_name="${servername}"
        else
            server_name=$(echo "${server_name}"; echo "${servername}")
        fi

        idy=$((${idy} + 1))
    done

    host_type=''

    # check if server vhost != host
    if [ -n "${server_name}" ]
    then
        if echo "${server_name}" | grep -q "${inst_servername}"
        then
            host_type='v'
        fi
    fi

    # added prefix to host
    if [ ${inst_servername} != ${main_servername} ]
    then
        host_type='v'
    fi

    # create dir if !exist
    mkdir -m 0750 -p ${vhost_include_path}

    echo "Include ${vhost_include_path}/${package_name}-${inst_alias}.conf" \
         >${vhost_alias_path}/${host_type}host-${inst_servername}-${inst_alias}
    chmod 0440 ${vhost_alias_path}/${host_type}host-${inst_servername}-${inst_alias}

    _vhost_exist=true
}

# ---------------------------------------------------------------------------
# create httpd project
# ---------------------------------------------------------------------------
create_httpd_project()
{
    eval _ac_con='${'${project_name}'_ACCESS_CONTROL}'

    # check for webaccess
    if [ "${_ac_con:-no}" = "yes" ]
    then
        eval _ac_all='${'${project_name}'_ACCESS_ALL}'

        _ac_auth=''
        _ac_host=''
        _ac_ip=''
        _ac_local=''
        if [ "${_ac_all:-yes}" != "yes" ]
        then
            eval  _ac_auth='${'${project_name}'_ACCESS_AUTH}'
            eval  _ac_host='${'${project_name}'_ACCESS_HOST}'
            eval    _ac_ip='${'${project_name}'_ACCESS_IP}'
            eval _ac_local='${'${project_name}'_ACCESS_LOCAL}'
        fi
    fi

    eval _sub='${'${project_name}'_SUBDOMAIN}'

    # phpmyadmin.my.lan
    if [ "${_sub:-no}" = "yes" ]
    then
        eval _sub_domain='${'${project_name}'_SUBDOMAIN_NAME}'
        eval   _sub_port='${'${project_name}'_SUBDOMAIN_PORT}'
        eval  _sub_admin='${'${project_name}'_SUBDOMAIN_ADMIN}'

        eval     sub_ssl='${'${project_name}'_SUBDOMAIN_FORCE_SSL}'

        myecho "Write subdomain '${_sub_domain}' config ..."

        _host_active=false
        _sub_active=true
        _host_ssl=false
        _sub_ssl=false
        if [ "${sub_ssl:-no}" = "yes" ]
        then
            _sub_ssl=true
            add_httpd_project 'virtual-http-short'

            eval _sub_port='${'${project_name}'_SUBDOMAIN_SSL_PORT}'
            eval _sub_cert='${'${project_name}'_SUBDOMAIN_SSL_CERT}'

            add_httpd_project 'virtual-https'
        else
            add_httpd_project 'virtual-http'
        fi

        create_logrotate
    fi

    eval _host='${'${project_name}'_HOST}'

    # eis.my.lan/phpmyadmin
    if [ "${_host:-no}" = "yes" ]
    then
        eval servername='${'${project_name}'_HOST_NAME}'
        eval      alias='${'${project_name}'_HOST_ALIAS}'

        eval   host_ssl='${'${project_name}'_HOST_FORCE_SSL}'

        myecho "Write domain '${servername}/${alias}' config ..."

        _host_active=true
        _sub_active=false
        _sub_ssl=false
        _host_ssl=false
        if [ "${host_ssl:-no}" = "yes" ]
        then
            _host_ssl=true
        fi

        add_httpd_project 'http'
    fi
}

# ---------------------------------------------------------------------------
# add httpd project
# ---------------------------------------------------------------------------
add_httpd_project()
{
    # load digest only once
    load_basic=1
    load_digest=1
    access_auth=1

    http=false
    virtual_http=false
    virtual_https=false
    virtual_http_short=false
    conf_file=''

    case "${1}" in
    http)
        # http{s}://eis.my.lan/phpmyadmin
        http=true
        eval servername='${'${project_name}'_HOST_NAME}'
        eval alias='${'${project_name}'_HOST_ALIAS}'
        conf_file="${vhost_include_path}/${package_name}-${alias}.conf"
        ;;
    virtual-http)
        # http://phpmyadmin.my.lan
        virtual_http=true
        eval servername='${'${project_name}'_SUBDOMAIN_NAME}'
        conf_file="${vhost_enabled_path}/virtualhost-${package_name}-${servername}.conf"
        alias=''
        ;;
    virtual-http-short)
        # http://phpmyadmin.my.lan
        virtual_http_short=true
        eval servername='${'${project_name}'_SUBDOMAIN_NAME}'
        conf_file="${vhost_enabled_path}/virtualhost-${package_name}-${servername}.conf"
        alias=''
        ;;
    virtual-https)
        # https://phpmyadmin.my.lan
        virtual_https=true
        eval servername='${'${project_name}'_SUBDOMAIN_NAME}'
        conf_file="${vhost_enabled_path}/virtualhost-${package_name}-${servername}.conf"
        alias=''
        log='ssl_'
        ;;
    esac

    eval upload_dir='${'${project_name}'_UPLOAD_DIR}'

    if [ -n "${upload_dir}" ]
    then
        ext_folder=":${upload_dir}"
    fi

    eval save_dir='${'${project_name}'_SAVE_DIR}'

    if [ -n "${save_dir}" ]
    then
        ext_folder="${ext_folder}:${save_dir}"
    fi

    if ${http:-false} ||
       ${virtual_http:-false} ||
       ${virtual_http_short:-false}
    then
        if [ -d /usr/lib/apache2/modules ]
        then
            modules_path='/usr/lib/apache2/modules'
        elif [ -d /usr/local/apache2/modules ]
        then
            modules_path='/usr/local/apache2/modules'
        fi

# write httpd.conf addon file
cat > ${conf_file}   <<EOF
#----------------------------------------------------------------------------
# httpd.conf file generated by ${package_name} version: ${VERSION}
#
# phpMyAdmin
#
# Do not edit this file, edit /etc/config.d/${package_name}
# Creation Date: ${EISDATE} Time: ${EISTIME}
#----------------------------------------------------------------------------
EOF
    fi

    if ${http:-false}
    then
        cat >> ${conf_file} <<EOF
Alias /${inst_alias} "${package_path}/"
EOF
    fi

    # write VirtualHost header
    if ${virtual_http:-false} ||
       ${virtual_https:-false} ||
       ${virtual_http_short:-false}
    then
        cat >> ${conf_file}   <<EOF
<VirtualHost *:${_sub_port}>
EOF
    fi

    if ${_host_ssl:-false} ||
       ${_sub_ssl:-false}
    then
        if ${virtual_http:-false} ||
           ${http:-false} ||
           ${virtual_http_short:-false}
        then
            cat >> ${conf_file}   <<EOF
<IfModule !mod_rewrite.c>
    LoadModule mod_rewrite_module ${modules_path}/mod_rewrite.so
</IfModule>
# Rewrite url for '${project_name}' with SSL
RewriteEngine on
RewriteCond %{HTTPS} off
EOF
            if ${_host_ssl:-false}
            then
                cat >> ${conf_file} <<EOF
RewriteRule /${alias}$ https://%{HTTP_HOST}%{REQUEST_URI} [R=301,L]
EOF
            elif ${_sub_ssl:-false}
            then
                cat >> ${conf_file} <<EOF
RewriteRule ^(.*)$ https://%{HTTP_HOST}%{REQUEST_URI} [R=301,L]
EOF
            fi
        fi
    fi

    if ! ${virtual_http_short:-false}
    then
       # load digest module
        if [ "${_ac_auth:-no}" ]
        then
            if ${_sub_active:-false} &&
               ${_sub_ssl:-false} &&
               [ ${load_basic} -eq 1 ]
            then
                cat >> ${conf_file}   <<EOF
<IfModule !mod_auth_basic.c>
    LoadModule auth_basic_module ${modules_path}/mod_auth_basic.so
</IfModule>
EOF
                load_basic=0

            elif ${_sub_active:-false} &&
                 ! ${_sub_ssl:-false} &&
                 [ ${load_digest} -eq 1 ]
            then
                cat >> ${conf_file}   <<EOF
<IfModule !mod_auth_digest.c>
    LoadModule auth_digest_module ${modules_path}/mod_auth_digest.so
</IfModule>
EOF
                load_digest=0
            fi

            if ${_host_active:-false} &&
               ${_host_ssl:-false} &&
               [ ${load_basic} -eq 1 ]
            then
                cat >> ${conf_file}   <<EOF
<IfModule !mod_auth_basic.c>
    LoadModule auth_basic_module ${modules_path}/mod_auth_basic.so
</IfModule>
EOF
                load_basic=0

            elif ${_host_active:-false} &&
                 ! ${_host_ssl:-false} &&
                 [ ${load_digest} -eq 1 ]
            then
                cat >> ${conf_file}   <<EOF
<IfModule !mod_auth_digest.c>
    LoadModule auth_digest_module ${modules_path}/mod_auth_digest.so
</IfModule>
EOF
                load_digest=0
            fi
        fi
    fi

    # servername
    cat >> ${conf_file}   <<EOF
# phpMyAdmin/${servername}------------------------------------
EOF

    if ${virtual_https:-false}
    then
        cat >> ${conf_file}   <<EOF
SSLEngine On
SSLCertificateFile /etc/ssl/certs/${package_name}.pem
SSLCertificateKeyFile /etc/ssl/certs/${package_name}.pem
<Files ~ "\.(pl|cgi|shtml|phtml|php|php?)$">
    SSLOptions +StdEnvVars
</Files>
SetEnvIf User-Agent ".*MSIE.*" nokeepalive ssl-unclean-shutdown downgrade-1.0 force-response-1.0

EOF
    fi

    if ${virtual_http:-false} ||
       ${virtual_https:-false} ||
       ${virtual_http_short:-false}
    then
        cat >> ${conf_file}   <<EOF
ServerName ${_sub_domain}:${_sub_port}
ServerAdmin ${_sub_admin}
DocumentRoot ${package_path}

EOF
    fi

    if ! ${virtual_http_short:-false}
    then
        cat >> ${conf_file}   <<EOF
<Directory "${package_path}/">
    Options FollowSymLinks MultiViews
    AllowOverride None
    php_admin_flag register_globals off
    php_admin_flag magic_quotes_gpc off
    php_admin_flag allow_url_include off
    php_admin_flag allow_url_fopen off
    php_admin_flag zend.ze1_compatibility_mode off
    php_admin_flag safe_mode Off

    php_admin_value open_basedir "${package_path}:/var/lib/php5:${package_folder}/tmp:/tmp:/usr/share/doc/${package_name}:/etc/phpMyAdmin:/proc/meminfo:/proc/stat${ext_folder}"

    # customize suhosin
    php_admin_value suhosin.post.max_array_index_length 256
    php_admin_value suhosin.post.max_totalname_length 8192
    php_admin_value suhosin.post.max_vars 2048
    php_admin_value suhosin.request.max_array_index_length 256
    php_admin_value suhosin.request.max_totalname_length 8192
    php_admin_value suhosin.request.max_vars 2048
    # php settings
    php_value session.save_path ${package_folder}/tmp
    php_value session.gc_divisor 100
    DirectoryIndex index.php
EOF
    fi

    if ! ${virtual_http_short:-false}
    then
        if [ "${_ac_all}" = "yes" ]
        then
            cat >> ${conf_file}   <<EOF
    Require all granted
EOF
        fi

        if [ "${_ac_auth}" = "yes" ]
        then
            access_auth=0

            if ${_host_ssl:-false} ||
               ${_sub_ssl:-false}
            then

                cat >> ${conf_file}   <<EOF
    AuthType Basic
    AuthName "${package_name}"
    AuthBasicProvider file
    AuthUserFile ${package_folder}/${package_name}.bapasswd
    Require valid-user
EOF
            else

                cat >> ${conf_file}   <<EOF
    AuthType Digest
    AuthName "${package_name}"
    AuthDigestDomain ${servername}
    AuthDigestProvider file
    AuthUserFile ${package_folder}/${package_name}.htpasswd
    Require valid-user
EOF
            fi

            # for digest auth
            ht_passwd_file=$(find ${package_folder} \
                     -maxdepth 1 \
                     -type f \
                     -name "${package_name}.htpasswd")

            # for basic auth
            ba_passwd_file=$(find ${package_folder} \
                     -maxdepth 1 \
                     -type f \
                     -name "${package_name}.bapasswd")

            if [ -z "${ht_passwd_file}" ]
            then
                ht_passwd_file="${package_folder}/${package_name}.htpasswd"
                ht_pw=true
            fi

            if [ -z "${ba_passwd_file}" ]
            then
                ba_passwd_file="${package_folder}/${package_name}.bapasswd"
                ba_pw=true
            fi

            if ${ht_pw:-false} ||
               ${ba_pw:-false}
            then
                if [ ${check_pwgen} -eq 1 ]
                then
                     check_package "pwgen" "${pwgen_version}"
                     check_pwgen=${?}
                fi

                if [ ${check_pwgen} -eq 0 ]
                then
                    get_pwgen_passwd

                    if ${ht_pw:-false}
                    then
                        get_digest_entry --user dummy \
                                         --realm "${package_name}" \
                                         --passwd "${password}"

                        set_passwd -c --entry "${_passwd_entry}" \
                                      --file "${ht_passwd_file}"
                    fi

                    if ${ba_pw:-false}
                    then
                        get_basic_entry --user dummy \
                                        --passwd "${password}"

                        set_passwd -c --entry "${_passwd_entry}" \
                                      --file "${ba_passwd_file}"
                    fi


                    chown ${apache_user} "${ht_passwd_file}" "${ba_passwd_file}"
                    chmod 0600 "${ht_passwd_file}" "${ba_passwd_file}"
                fi
            fi
        fi

        if [ -n "${_ac_ip}" ]
        then
            cat >> ${conf_file}   <<EOF
    Require ip ${_ac_ip}
EOF
        fi

        if [ -n  "${_ac_host}" ]
        then
            cat >> ${conf_file}   <<EOF
    Require host ${_ac_host}
EOF
        fi

        if [ "${_ac_local}" = "yes" ]
        then
            cat >> ${conf_file}   <<EOF
    Require local
EOF
        fi

    cat >> ${conf_file}   <<EOF
</Directory>

<Directory "${package_path}/libraries">
    Require all denied
</Directory>
<Directory "${package_path}/templates">
    Require all denied
</Directory>

EOF
    fi

    if ${virtual_http:-false} ||
       ${virtual_https:-false} ||
       ${virtual_http_short:-false}
    then
        cat >> ${conf_file}   <<EOF
ErrorLog ${package_folder}/log/log.${log}error
CustomLog ${package_folder}/log/log.${log}access combined

</VirtualHost>

EOF
    fi

    chmod 0600 ${conf_file}
}

# ---------------------------------------------------------------------------
# apache start
# ---------------------------------------------------------------------------
apache_start()
{
    # reload apache2 configuration if apache is running
    if [ -f /run/httpd.pid ] ||
       [ -f /run/apache2.pid ] &&
       [ -f /etc/init.d/apache2 ]
    then
        /etc/init.d/apache2 stop
        sleep 5
        /etc/init.d/apache2 start
    fi
}

# ---------------------------------------------------------------------------
# remove vhost aliase
# ---------------------------------------------------------------------------
remove_vhost_alias_entry()
{
    eval servername='${'${project_name}'_HOST_NAME}'
    eval      alias='${'${project_name}'_HOST_ALIAS}'

    rm -f ${vhost_alias_path}/host-${servername}-${alias}
    rm -f ${vhost_alias_path}/vhost-${servername}-${alias}
}

# ---------------------------------------------------------------------------
# create certifikate link
# ---------------------------------------------------------------------------
create_cert()
{
    cert_path='/var/certs/ssl/certs'
    eval cert_name='${'${project_name}'_SUBDOMAIN_SSL_CERT}'
    cert_link="${package_name}.pem"

    eval sub='${'${project_name}'_SUBDOMAIN}'

    if [ "${sub:-no}" = "yes" ]
    then
        eval sub_ssl='${'${project_name}'_SUBDOMAIN_FORCE_SSL}'

        if [ "${sub_ssl:-no}" = "yes" ]
        then
            if [ -f ${cert_path}/${cert_name} ]
            then
                cd ${cert_path}
                rm -f ${cert_link}
                ln -sf ${cert_name} ${cert_link}
            fi
        fi
    fi
}

# ---------------------------------------------------------------------------
# create logrotate
# ---------------------------------------------------------------------------
create_logrotate()
{

    cat > /etc/logrotate.d/${package_name} <<EOF
#---------------------------------------------------------------------
# /etc/logrotate.d/${package_name} file generated by /var/install/config.d/${package_name}.sh
#
# Do not edit this file, edit /etc/config.d/${package_name}.sh
# Creation Date: ${EISDATE} Time: ${EISTIME}
#---------------------------------------------------------------------
${package_folder}/log/log.access ${package_folder}/log/log.ssl_access ${package_folder}/log/log.error ${package_folder}/log/log.ssl_error {
    weekly
    missingok
    rotate 10
    compress
    notifempty
    create 640 wwwrun nogroup
    sharedscripts
    postrotate
        /etc/init.d/apache2 restart > /dev/null
    endscript
}
EOF

}

# ---------------------------------------------------------------------------
# check package
# ---------------------------------------------------------------------------
check_package()
{
    local package="${1}"
    local version="${2}"
    local retvar

    local installed=$(eisman check "${package}" ${version})

    if [ "${installed}" = "not-installed" ] ||
       [ "${installed}" = "new" ]
    then
        if ! ${quietmode:-false}
        then
            if [ -n "${version}" ]
            then
                version="=${version}"
            fi

            eisman install --auto --unstable ${package}${version}
            retvar=${?}
        fi
    else
        retvar=0
    fi

    return  ${retvar:-0}
}

# ---------------------------------------------------------------------------
# my echo
# ---------------------------------------------------------------------------
myecho()
{
    if ! ${quietmode:-false}
    then
        echo "${@}"
    fi
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
# include passwdlib
. /var/install/include/passwdlib

quietmode=false

while [ ${#} -gt 0 ]
do
    case ${1} in
    --no-check)
        _no_check=true
        shift
        ;;
    --quiet)
        quietmode=true
        shift
        ;;
    esac
done

eval can_start='${START_'${project_name}'}'

if [ "${can_start:-no}" = 'yes' ]
then
    if ! "${_no_check:-false}"
    then
        _old_cfg="/tmp/edit-${package_name}-*"

        if [ -n "${_old_cfg}" ]
        then
            # run in a subshell, so it won't step over our vars:
            (
                . ${_old_cfg}
                vhost_alias_path='/etc/apache2/vhost'
                create_vhosts 'remove'
                if "${_apache_conf:-false}"
                then
                    /var/install/config.d/apache2.sh 2>/dev/null
                fi
            )
        fi
    fi

    mkdir -m 0750 -p ${vhost_alias_path}
    mkdir -m 0750 -p ${vhost_include_path}

    ${RM} -f ${vhost_include_path}/${package_name}-*.conf
    ${RM} -f ${vhost_enabled_path}/virtualhost-${package_name}-*.conf
    ${RM} -f /etc/logrotate.d/${package_name}

    old_vhost_conf="${vhost_available_path}/${package_name}.conf"
    if [ -f "${old_vhost_conf}" ]
    then
        ${RM} -f ${vhost_enabled_path}/${package_name}.conf
        ${RM} -f ${vhost_available_path}/${package_name}.conf
        _vhost_exist=true
    fi

    old_virtual_conf="${vhost_available_path}/virtualhost-${package_name}.conf"
    if [ -f "${old_virtual_conf}" ]
    then
        ${RM} -f ${vhost_available_path}/virtualhost-${package_name}.conf
        ${RM} -f ${vhost_enabled_path}/virtualhost-${package_name}.conf
    fi

    checkCredentials
    createBooleanValues
    createConfigIncPhp

    create_vhosts 'add'

    create_httpd_project

    # do not rehash with update
    if ! "${_no_check:-false}"
    then
        create_cert
    fi

    if ${_vhost_exist:-false}
    then
        /var/install/config.d/apache2.sh 2>/dev/null
    fi

    # reload apache2 configuration if apache is running
    apache_start

    # add or remove menu entry for user web access handling
    if [ ${access_auth} -eq 0 ]
    then
        /var/install/bin/add-menu --script \
            setup.services.apache2.config.modules.${package_name}.menu \
            "apache2-config-modules-common-web-user ${package_name}" \
            'User handling for web access'
    else
        /var/install/bin/del-menu \
            setup.services.apache2.config.modules.${package_name}.menu \
            apache2-config-modules-common-web-user
    fi
else
    create_vhosts 'remove'
    ${RM} -f ${vhost_include_path}/${package_name}-*.conf
    ${RM} -f ${vhost_enabled_path}/virtualhost-${package_name}-*.conf
    ${RM} -f /etc/logrotate.d/${package_name}

    old_vhost_conf="${vhost_available_path}/${package_name}.conf"
    if [ -f "${old_vhost_conf}" ]
    then
        ${RM} -f ${vhost_enabled_path}/${package_name}.conf
        ${RM} -f ${vhost_available_path}/${package_name}.conf
        _vhost_exist=true
    fi

    old_virtual_conf="${vhost_available_path}/virtualhost-${package_name}.conf"
    if [ -f "${old_virtual_conf}" ]
    then
        ${RM} -f ${vhost_available_path}/virtualhost-${package_name}.conf
        ${RM} -f ${vhost_enabled_path}/virtualhost-${package_name}.conf
    fi

    if "${_apache_conf:-false}" || "${_vhost_exist:-false}"
    then
        /var/install/config.d/apache2.sh 2>/dev/null
    fi
    apache_start

    # remove menu entry
    /var/install/bin/del-menu \
        setup.services.apache2.config.modules.${package_name}.menu \
        apache2-config-modules-common-web-user
fi


exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
